@@ -1,6 +1,6 @@
 package Enbld::Definition::Tree;
 
-use 5.012;
+use strict;
 use warnings;
 
 use parent qw/Enbld::Definition/;
@@ -13,7 +13,7 @@ sub initialize {
     $self->{defined}{ArchiveName}       =   'tree';
     $self->{defined}{WebSite}           =
         'http://mama.indstate.edu/users/ice/tree/';
-    $self->{defined}{AdditionalArgument} = \&set_args;
+    $self->{defined}{DarwinArgument}    = \&set_args;
     $self->{defined}{VersionForm}       =   '1\.\d\.\d';
     $self->{defined}{Extension}         =   'tgz';
     $self->{defined}{DownloadSite}      =
@@ -22,9 +22,7 @@ sub initialize {
     $self->{defined}{Prefix}            =   'prefix=';
 
     $self->{defined}{CommandConfigure}  =   '';
-    $self->{defined}{CommandMake}       =   'make';
     $self->{defined}{CommandTest}       =   '';
-    $self->{defined}{CommandInstall}    =   'make install';
 
     return $self;
 }
