@@ -1,6 +1,6 @@
 package Enbld::Deployed;
 
-use 5.012;
+use strict;
 use warnings;
 
 our %deployed;
